import unittest
import datetime
import decimal
import json

from robit import Worker

wo = Worker('Testy McTesterson')


class TestRobit(unittest.TestCase):
    def test_robit(self):
        self.assertTrue(True)

